@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmAuth.cc 9045 2017-04-12 10:20:35Z dwm $
+// @(#) $Id: DwmAuth.cc 10617 2020-05-02 21:18:04Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -55,7 +55,7 @@ extern "C" {
 #include "DwmAuthCountedString.hh"
 #include "DwmAuth.hh"
 
-static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuth.cc 9045 $");
+static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuth.cc 10617 $");
 
 //----------------------------------------------------------------------------
 //!  Maximum length of string we'll accept during authentication.  This is
@@ -70,6 +70,7 @@ namespace Dwm {
 
   namespace Auth {
 
+#if 0
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -80,14 +81,13 @@ namespace Dwm {
 #else
       CryptoPP::BlockingRng  rng;
 #endif
-      byte  buf[sz];
+      uint8_t  buf[sz];
       rng.GenerateBlock(buf, sz);
       string  s;
       s.assign((const char *)buf, sz);
       return s;
     }
 
-#if 0
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -138,6 +138,7 @@ namespace Dwm {
       return os.str();
     }
 
+#if 0
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -258,7 +259,8 @@ namespace Dwm {
       }
       return rc;
     }
-
+#endif
+    
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -266,7 +268,7 @@ namespace Dwm {
     {
       string  sb;
       CryptoPP::StringSource
-        ss((byte *)(s.c_str()), s.size(), true,
+        ss((uint8_t *)(s.c_str()), s.size(), true,
            new CryptoPP::Base64Encoder(new CryptoPP::StringSink(sb), false));
       return sb;
     }
