@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthPKCrypto.cc 8992 $
-// @(#) $Id: DwmAuthPKCrypto.cc 8992 2017-04-08 13:05:45Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthPKCrypto.cc 9849 $
+// @(#) $Id: DwmAuthPKCrypto.cc 9849 2017-12-18 23:28:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -54,7 +54,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmAuthPKCrypto.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthPKCrypto.cc 8992 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthPKCrypto.cc 9849 $");
 
 using namespace std;
 using CryptoPP::Base64Decoder;
@@ -246,7 +246,7 @@ namespace Dwm {
       string  s = ToString();
       string  sb;
       CryptoPP::StringSource
-        ss((byte *)(s.c_str()), s.size(), true,
+        ss((uint8_t *)(s.c_str()), s.size(), true,
            new CryptoPP::Base64Encoder(new CryptoPP::StringSink(sb), false));
       return sb;
     }
@@ -278,7 +278,7 @@ namespace Dwm {
       if (! s.empty()) {
         string  decoded;
         CryptoPP::StringSource
-          ss2((const byte *)(s.c_str()), s.size(), true,
+          ss2((const uint8_t *)(s.c_str()), s.size(), true,
               new Base64Decoder(new StringSink(decoded)));
         rc = FromString(decoded);
       }
@@ -474,7 +474,7 @@ namespace Dwm {
       string  s = ToString();
       string  sb;
       CryptoPP::StringSource
-        ss((byte *)(s.c_str()), s.size(), true,
+        ss((uint8_t *)(s.c_str()), s.size(), true,
            new CryptoPP::Base64Encoder(new CryptoPP::StringSink(sb), false));
       return sb;
     }
@@ -489,6 +489,22 @@ namespace Dwm {
       return true;
     }
 
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    bool PKCrypto::PrivateKey::FromBase64String(const std::string & s)
+    {
+      bool  rc = false;
+      if (! s.empty()) {
+        string  decoded;
+        CryptoPP::StringSource
+          ss2((const uint8_t *)(s.c_str()), s.size(), true,
+              new Base64Decoder(new StringSink(decoded)));
+        rc = FromString(decoded);
+      }
+      return rc;
+    }
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
