@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmAuthPeerAuthenticator.cc 9028 2017-04-12 01:18:31Z dwm $
+// @(#) $Id: DwmAuthPeerAuthenticator.cc 10617 2020-05-02 21:18:04Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -44,11 +44,13 @@ extern "C" {
   #include <sys/socket.h>
   #include <sys/un.h>
   #include <netinet/in.h>
+  #include <netinet/tcp.h>
   #include <arpa/inet.h>
   #include <pwd.h>
   #include <unistd.h>
 }
 
+#include <cassert>
 #include <sstream>
 #include <cryptopp/cryptlib.h>
 #include <cryptopp/rsa.h>
@@ -61,7 +63,7 @@ extern "C" {
 #include "DwmAuthPeerAuthenticator.hh"
 #include "DwmAuthSymCrypto.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthPeerAuthenticator.cc 9028 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthPeerAuthenticator.cc 10617 $");
 
 using namespace std;
 using CryptoPP::PSS;
@@ -88,7 +90,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     static CryptoPP::SecByteBlock to_SecByteBlock(const string & s)
     {
-      return CryptoPP::SecByteBlock((const byte *)s.c_str(), s.size());
+      return CryptoPP::SecByteBlock((const uint8_t *)s.c_str(), s.size());
     }
 
     //------------------------------------------------------------------------
@@ -96,17 +98,19 @@ namespace Dwm {
     //------------------------------------------------------------------------
     PeerAuthenticator::PeerAuthenticator(const string & myPrivKeyPath,
                                          const string & pubKeysPath)
-        : _myPrivKeyPath(myPrivKeyPath), _pubKeysPath(pubKeysPath)
+        : _pubKeysPath(pubKeysPath)
     {
+      std::string  privKeyPath = myPrivKeyPath;
+      
       struct passwd  *pw = 0;
-      if (_myPrivKeyPath.empty() || _pubKeysPath.empty()) {
+      if (privKeyPath.empty() || _pubKeysPath.empty()) {
         uid_t   uid = getuid();
         pw = getpwuid(uid);
       }
-      if (_myPrivKeyPath.empty()) {
+      if (privKeyPath.empty()) {
         if (pw) {
-          _myPrivKeyPath = pw->pw_dir;
-          _myPrivKeyPath += "/.dwmauth/id_rsa";
+          privKeyPath = pw->pw_dir;
+          privKeyPath += "/.dwmauth/id_ed25519";
         }
       }
       if (_pubKeysPath.empty()) {
@@ -115,8 +119,27 @@ namespace Dwm {
           _pubKeysPath += "/.dwmauth/known_services";
         }
       }
+      assert(_myKeys.Load(privKeyPath, _myId));
     }
-    
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    PeerAuthenticator::PeerAuthenticator(const std::string & myId,
+                                         const Ed25519::KeyPair & keyPair,
+                                         const std::string & pubKeysPath)
+        : _myId(myId), _myKeys(keyPair), _pubKeysPath(pubKeysPath)
+    {
+      if (_pubKeysPath.empty()) {
+        uid_t           uid = getuid();
+        struct passwd  *pw = getpwuid(uid);
+        if (pw) {
+          _pubKeysPath = pw->pw_dir;
+          _pubKeysPath += "/.dwmauth/known_services";
+        }
+      }
+    }
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -125,16 +148,25 @@ namespace Dwm {
     {
       bool  rc = false;
       if (fd >= 0) {
-        string  &&mypubEC = to_str(agreement.Public());
+        string  mypubEC = to_str(agreement.Public());
         if (IO::Write(fd, mypubEC) == IO::StreamedLength(mypubEC)) {
           string  theirPubECDH;
           if (IO::Read(fd, theirPubECDH) > 0) {
             agreement.TheirPublic(to_SecByteBlock(theirPubECDH));
-            CryptoPP::SecByteBlock  agreedKeyBB;
+            // CryptoPP::SecByteBlock  agreedKeyBB;
             if (agreement.Agree()) {
               rc = true;
             }
+            else {
+              Syslog(LOG_ERR, "Failed to reach agreement");
+            }
           }
+          else {
+            Syslog(LOG_ERR, "Read(%d) failed: %m", fd);
+          }
+        }
+        else {
+          Syslog(LOG_ERR, "Write(%d) failed: %m", fd);
         }
       }
       return rc;
@@ -144,16 +176,17 @@ namespace Dwm {
     //!  
     //------------------------------------------------------------------------
     string PeerAuthenticator
-    ::BuildIDAndSignature(const string & myId,
-                          const PKCrypto::PrivateKey & myPrivRSAKey,
-                          const ECDHAgreement & agreement)
+    ::BuildIDAndSignature(const ECDHAgreement & agreement)
     {
       string  agreedKeyStr(to_str(agreement.AgreedKey()));
       string  keystr(agreedKeyStr.substr(0, 16));
       string  ivstr(agreedKeyStr.substr(16, 16));
-      string  myIdCrypted = SymCrypto::Encrypt(keystr, ivstr, myId);
+      string  myIdCrypted = SymCrypto::Encrypt(keystr, ivstr, _myId);
       string  msgToSign(to_str(agreement.Public()) + myIdCrypted);
-      RSASS<PSS,SHA256>::Signer  signer(myPrivRSAKey);
+      CryptoPP::ByteQueue  bt;
+      _myKeys.Private().Save(bt, true);
+
+      CryptoPP::ed25519::Signer  signer(bt);
       string  mySignature;
       CryptoPP::AutoSeededRandomPool  rng;
       StringSource ss(msgToSign, true,
@@ -169,8 +202,7 @@ namespace Dwm {
     //!  
     //------------------------------------------------------------------------
     bool PeerAuthenticator
-    ::IDAndSigExchange(int fd, const string & myId,
-                       const PKCrypto::PrivateKey & myPrivRSAKey,
+    ::IDAndSigExchange(int fd,
                        const ECDHAgreement & agreement,
                        string & theirId,
                        string & theirIdCrypted,
@@ -178,7 +210,7 @@ namespace Dwm {
     {
       bool  rc = false;
       if (fd >= 0) {
-        string idAndSig = BuildIDAndSignature(myId, myPrivRSAKey, agreement);
+        string idAndSig = BuildIDAndSignature(agreement);
         if (IO::Write(fd, idAndSig)) {
           string  s;
           if (IO::Read(fd, s) > 0) {
@@ -190,32 +222,25 @@ namespace Dwm {
               if (IO::Read(is, theirSig)) {
                 rc = true;
               }
+              else {
+                Syslog(LOG_ERR, "Failed to read signature");
+              }
+            }
+            else {
+              Syslog(LOG_ERR, "Failed to read encrypted ID");
             }
           }
+          else {
+            Syslog(LOG_ERR, "Failed to read ID and signature from %d", fd);
+          }
+        }
+        else {
+          Syslog(LOG_ERR, "Failed to write ID and signature to %d", fd);
         }
       }
       return rc;
     }
 
-#if 0
-    bool PeerAuthenticator::VerifySignature()
-    {
-      Auth::PublicKeysFile  pubKeysFile;
-      pubKeysFile.Load(_pubKeysPath);
-      PublicKeysFile::Map::const_iterator  pki =
-        pubKeysFile.Find(theirId);
-      if (pki != pubKeysFile.Keys().end()) {
-        string  msgToVerify = theirPubECDH + theirIdCrypted;
-        RSASS<PSS,SHA256>::Verifier  verifier(pki->second);
-        if (verifier.VerifyMessage((const byte *)msgToVerify.c_str(),
-                                   msgToVerify.size(),
-                                   (const byte *)theirSig.c_str(),
-                                   theirSig.size())) {
-        }
-      }
-    }
-#endif
-    
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -223,53 +248,50 @@ namespace Dwm {
                                          string & agreedKey)
     {
       bool  rc = false;
+      theirId.clear();
+      agreedKey.clear();
       if (fd >= 0) {
         struct sockaddr_in  sockAddr;
         socklen_t           sockLen = sizeof(sockAddr);
         getpeername(fd, (struct sockaddr *)&sockAddr, &sockLen);
-        
+
+        int tcpNoDelay = 1;
+        setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&tcpNoDelay,
+                   sizeof(tcpNoDelay));
         Auth::ECDHAgreement  agreement;
         if (ECExchange(fd, agreement)) {
-          PKCrypto::KeyPair  myKeys;
-          string             myId;
-          if (myKeys.Load(_myPrivKeyPath, myId)) {
-            string  theirIdCrypted, theirSig;
-            if (IDAndSigExchange(fd, myId, myKeys.Private(),
-                                 agreement, theirId,
-                                 theirIdCrypted, theirSig)) {
-              Auth::PublicKeysFile  pubKeysFile;
-              pubKeysFile.Load(_pubKeysPath);
-              PublicKeysFile::Map::const_iterator  pki =
-                pubKeysFile.Find(theirId);
-              if (pki != pubKeysFile.Keys().end()) {
-                string  msgToVerify =
-                  to_str(agreement.TheirPublic()) + theirIdCrypted;
-                RSASS<PSS,SHA256>::Verifier  verifier(pki->second);
-                if (verifier.VerifyMessage((const byte *)msgToVerify.c_str(),
-                                           msgToVerify.size(),
-                                           (const byte *)theirSig.c_str(),
-                                           theirSig.size())) {
-                  agreedKey = to_str(agreement.AgreedKey());
-                  rc = true;
-                }
-                else {
-                  Syslog(LOG_ERR, "Failed to verify message from %s",
-                         theirId.c_str());
-                }
+          string  theirIdCrypted, theirSig;
+          if (IDAndSigExchange(fd, agreement, theirId,
+                               theirIdCrypted, theirSig)) {
+            Auth::PublicKeysFile  pubKeysFile;
+            pubKeysFile.Load(_pubKeysPath);
+            Ed25519::PublicKey  theirPubKey;
+            if (pubKeysFile.Find(theirId, theirPubKey)) {
+              string  msgToVerify =
+                to_str(agreement.TheirPublic()) + theirIdCrypted;
+              CryptoPP::ByteQueue  bt;
+              theirPubKey.Save(bt);
+              CryptoPP::ed25519::Verifier  verifier(bt);
+              if (verifier.VerifyMessage((const uint8_t *)msgToVerify.c_str(),
+                                         msgToVerify.size(),
+                                         (const uint8_t *)theirSig.c_str(),
+                                         theirSig.size())) {
+                agreedKey = to_str(agreement.AgreedKey());
+                rc = true;
               }
               else {
-                Syslog(LOG_ERR, "Failed to find %s in %s",
-                       theirId.c_str(), _pubKeysPath.c_str());
+                Syslog(LOG_ERR, "Failed to verify message from %s",
+                       theirId.c_str());
               }
             }
             else {
-              Syslog(LOG_ERR, "ID and signature exhange with %s failed",
-                     inet_ntoa(sockAddr.sin_addr));
+              Syslog(LOG_ERR, "Failed to find %s in %s",
+                     theirId.c_str(), _pubKeysPath.c_str());
             }
           }
           else {
-            Syslog(LOG_ERR, "Failed to load RSA key from %s",
-                   _myPrivKeyPath.c_str());
+            Syslog(LOG_ERR, "ID and signature exhange with %s failed",
+                   inet_ntoa(sockAddr.sin_addr));
           }
         }
         else {
