@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthSymCrypto.cc 8641 $
-// @(#) $Id: DwmAuthSymCrypto.cc 8641 2016-06-08 12:24:27Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthSymCrypto.cc 9844 $
+// @(#) $Id: DwmAuthSymCrypto.cc 9844 2017-12-16 23:58:55Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -51,7 +51,7 @@
 #include "DwmSysLogger.hh"
 #include "DwmAuthSymCrypto.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthSymCrypto.cc 8641 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthSymCrypto.cc 9844 $");
 
 using namespace std;
 
@@ -71,8 +71,8 @@ namespace Dwm {
         using namespace CryptoPP;
         using AEF = AuthenticatedEncryptionFilter;
         
-        byte  key[AES::DEFAULT_KEYLENGTH];
-        byte  iv[AES::BLOCKSIZE];
+        uint8_t  key[AES::DEFAULT_KEYLENGTH];
+        uint8_t  iv[AES::BLOCKSIZE];
         for (uint8_t i = 0; i < (sizeof(key)/sizeof(key[0])); ++i) {
           key[i] = keystr[i % keystr.size()];
         }
@@ -95,6 +95,42 @@ namespace Dwm {
         }
         return ciphertext;
       }
+
+      //----------------------------------------------------------------------
+      //!  
+      //----------------------------------------------------------------------
+      string Encrypt(const string & keystr,
+                     const string & ivstr,
+                     const uint8_t *plaintext,
+                     size_t plaintextLen)
+      {
+        using namespace CryptoPP;
+        using AEF = AuthenticatedEncryptionFilter;
+        
+        uint8_t  key[AES::DEFAULT_KEYLENGTH];
+        uint8_t  iv[AES::BLOCKSIZE];
+        for (uint8_t i = 0; i < (sizeof(key)/sizeof(key[0])); ++i) {
+          key[i] = keystr[i % keystr.size()];
+        }
+        for (uint8_t i = 0; i < (sizeof(iv)/sizeof(iv[0])); ++i) {
+          iv[i] = ivstr[i % ivstr.size()];
+        }
+        string  ciphertext;
+        try {
+          GCM<AES>::Encryption  enc;
+          const int  TAGSIZE = 16;
+          enc.SetKeyWithIV(key, sizeof(key), iv, sizeof(iv));
+          memset(key, 0, sizeof(key));
+          memset(iv, 0, sizeof(iv));
+          StringSource(plaintext, plaintextLen, true,
+                       new AEF(enc, new StringSink(ciphertext),
+                               false, TAGSIZE));
+        }
+        catch (CryptoPP::Exception & e) {
+          Syslog(LOG_ERR, "Exception: %s", e.what());
+        }
+        return ciphertext;
+      }
       
       //----------------------------------------------------------------------
       //!  
@@ -106,9 +142,9 @@ namespace Dwm {
         using namespace CryptoPP;
         using ADF = AuthenticatedDecryptionFilter;
         
-        string  plaintext;
-        byte    key[AES::DEFAULT_KEYLENGTH];
-        byte    iv[AES::BLOCKSIZE];
+        string   plaintext;
+        uint8_t  key[AES::DEFAULT_KEYLENGTH];
+        uint8_t  iv[AES::BLOCKSIZE];
         for (uint8_t i = 0; i < (sizeof(key)/sizeof(key[0])); ++i) {
           key[i] = keystr[i % keystr.size()];
         }
