@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthSymCryptoMessage.cc 9129 $
-// @(#) $Id: DwmAuthSymCryptoMessage.cc 9129 2017-04-16 23:23:51Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthSymCryptoMessage.cc 9848 $
+// @(#) $Id: DwmAuthSymCryptoMessage.cc 9848 2017-12-18 22:25:38Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -53,7 +53,7 @@ extern "C" {
 #include "DwmAuthSymCrypto.hh"
 #include "DwmAuthSymCryptoMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/src/DwmAuthSymCryptoMessage.cc 9129 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/src/DwmAuthSymCryptoMessage.cc 9848 $");
 
 using namespace std;
 
@@ -165,6 +165,19 @@ namespace Dwm {
       {
         ssize_t  rc = -1;
         if (fd >= 0) {
+#if 1
+          ostringstream  oss;
+          oss.write((const char *)_iv, sizeof(_iv));
+          WriteMsgValue(oss);
+          string   s = oss.str();
+          ssize_t  bytesWritten = write(fd, s.c_str(), s.size());
+          if (bytesWritten == s.size()) {
+            rc = bytesWritten;
+          }
+          else {
+            rc = -1;
+          }
+#else
           ssize_t  bytesWritten = write(fd, _iv, sizeof(_iv));
           if (bytesWritten == sizeof(_iv)) {
             rc = bytesWritten;
@@ -176,6 +189,7 @@ namespace Dwm {
               rc = -1;
             }
           }
+#endif
         }
         return rc;
       }
