@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/tests/TestDwmAuth.cc 9045 $
-// @(#) $Id: TestDwmAuth.cc 9045 2017-04-12 10:20:35Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/tests/TestDwmAuth.cc 10617 $
+// @(#) $Id: TestDwmAuth.cc 10617 2020-05-02 21:18:04Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -56,7 +56,7 @@ extern "C" {
 #include "DwmAuth.hh"
 #include "DwmAuthCountedString.hh"
 
-static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/tests/TestDwmAuth.cc 9045 $");
+static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/tests/TestDwmAuth.cc 10617 $");
 
 using namespace std;
 using namespace Dwm;
@@ -77,8 +77,8 @@ void ClientThread()
     sockAddr.sin_port = htons(2121);
     sockAddr.sin_addr.s_addr = inet_addr("127.0.0.1");
     if (UnitAssert(s.Connect(sockAddr))) {
-      Auth::PKCrypto::KeyPair  myKeys =
-        Auth::PKCrypto::CreateKeyPair(2048);
+      Auth::Ed25519::KeyPair  myKeys =
+        Auth::Ed25519::CreateKeyPair();
       UnitAssert(AuthenticateServer(s, myKeys, "DwmAuthTest"));
     }
     UnitAssert(s.Close());
@@ -106,8 +106,8 @@ void ServerThread()
         Socket  as;
         struct sockaddr_in  clientAddr;
         if (UnitAssert(s.Accept(as, clientAddr))) {
-          Auth::PKCrypto::KeyPair  myKeys =
-            Auth::PKCrypto::CreateKeyPair(2048);
+          Auth::Ed25519::KeyPair  myKeys =
+            Auth::Ed25519::CreateKeyPair();
           UnitAssert(AuthenticateClient(as, myKeys, "DwmAuthTest"));
         }
       }
