@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: TestDwmAuthPeerAuthenticator.cc 9045 2017-04-12 10:20:35Z dwm $
+// @(#) $Id: TestDwmAuthPeerAuthenticator.cc 10617 2020-05-02 21:18:04Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017
 //  All rights reserved.
@@ -63,7 +63,7 @@ extern "C" {
 #include "DwmAuthECDHAgreement.hh"
 #include "DwmAuthPeerAuthenticator.hh"
 
-static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/tests/TestDwmAuthPeerAuthenticator.cc 9045 $");
+static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/tests/TestDwmAuthPeerAuthenticator.cc 10617 $");
 
 using namespace std;
 using namespace Dwm;
@@ -71,7 +71,7 @@ using namespace Dwm;
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-void ClientThread()
+void ClientThread(bool preloadKeys)
 {
   Socket  s;
   if (UnitAssert(s.Open(PF_INET, SOCK_STREAM, 0))) {
@@ -85,11 +85,25 @@ void ClientThread()
     sockAddr.sin_port = htons(2525);
     sockAddr.sin_addr.s_addr = inet_addr("127.0.0.1");
     if (UnitAssert(s.Connect(sockAddr))) {
-      Auth::PeerAuthenticator  peerAuth("./id_rsa", "./known_services");
-      string                   theirid, agreedKey;
-      UnitAssert(peerAuth.Authenticate(s, theirid, agreedKey));
-      UnitAssert(! theirid.empty());
-      UnitAssert(! agreedKey.empty());
+      if (preloadKeys) {
+        string                   myId;
+        Auth::Ed25519::KeyPair   myKeys;
+        if (UnitAssert(myKeys.Load("./id_ed25519", myId))) {
+          Auth::PeerAuthenticator  peerAuth(myId, myKeys,
+                                            "./known_services");
+          string                   theirid, agreedKey;
+          UnitAssert(peerAuth.Authenticate(s, theirid, agreedKey));
+          UnitAssert(! theirid.empty());
+          UnitAssert(! agreedKey.empty());
+        }
+      }
+      else {
+        Auth::PeerAuthenticator  peerAuth("./id_ed25519", "./known_services");
+        string                   theirid, agreedKey;
+        UnitAssert(peerAuth.Authenticate(s, theirid, agreedKey));
+        UnitAssert(! theirid.empty());
+        UnitAssert(! agreedKey.empty());
+      }
     }
     UnitAssert(s.Close());
   }
@@ -101,7 +115,7 @@ static volatile bool g_serverStarted = false;
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
-void ServerThread()
+void ServerThread(bool preloadKeys)
 {
   Socket  s;
   if (UnitAssert(s.Open(PF_INET, SOCK_STREAM, 0))) {
@@ -122,12 +136,27 @@ void ServerThread()
         Socket  as;
         struct sockaddr_in  clientAddr;
         if (UnitAssert(s.Accept(as, clientAddr))) {
-          Auth::PeerAuthenticator  peerAuth("./id_rsa", "./authorized_keys");
-          string                   theirid, agreedKey;
-          UnitAssert(peerAuth.Authenticate(as, theirid, agreedKey));
-          UnitAssert(! theirid.empty());
-          UnitAssert(! agreedKey.empty());
-          UnitAssert(as.Close());
+          if (preloadKeys) {
+            string                   myId;
+            Auth::Ed25519::KeyPair  myKeys;
+            if (UnitAssert(myKeys.Load("./id_ed25519", myId))) {
+              Auth::PeerAuthenticator  peerAuth(myId, myKeys,
+                                                "./authorized_keys");
+              string                   theirid, agreedKey;
+              UnitAssert(peerAuth.Authenticate(as, theirid, agreedKey));
+              UnitAssert(! theirid.empty());
+              UnitAssert(! agreedKey.empty());
+              UnitAssert(as.Close());
+            }
+          }
+          else {
+            Auth::PeerAuthenticator  peerAuth("./id_ed25519", "./authorized_keys");
+            string                   theirid, agreedKey;
+            UnitAssert(peerAuth.Authenticate(as, theirid, agreedKey));
+            UnitAssert(! theirid.empty());
+            UnitAssert(! agreedKey.empty());
+            UnitAssert(as.Close());
+          }
         }
       }
     }
@@ -141,13 +170,23 @@ void ServerThread()
 //----------------------------------------------------------------------------
 int main(int argc, char *argv[])
 {
-  //  SysLogger::Open("TestECDH", LOG_PERROR, LOG_USER);
+  // SysLogger::Open("TestDwmAuthPeerAuthenticator", LOG_PERROR, LOG_USER);
 
-  thread  serverThread(ServerThread);
-  while (! g_serverStarted) {}
-  thread  clientThread(ClientThread);
-  clientThread.join();
-  serverThread.join();
+  vector<pair<bool,bool>> preloadKeys = {
+    { false, false },
+    { false, true },
+    { true, true },
+    { true, false }
+  };
+
+  for (auto preload : preloadKeys) {
+    g_serverStarted = false;
+    thread  serverThread(ServerThread, preload.first);
+    while (! g_serverStarted) {}
+    thread  clientThread(ClientThread, preload.second);
+    clientThread.join();
+    serverThread.join();
+  }
   
   int  rc;
   if (Assertions::Total().Failed()) {
