@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/tests/TestDwmAuthSymCrypto.cc 8556 $
-// @(#) $Id: TestDwmAuthSymCrypto.cc 8556 2016-05-22 14:43:14Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/tests/TestDwmAuthSymCrypto.cc 9842 $
+// @(#) $Id: TestDwmAuthSymCrypto.cc 9842 2017-12-16 23:55:16Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -39,16 +39,58 @@
 //!  \brief Unit tests for Dwm::Auth::SymCrypto
 //---------------------------------------------------------------------------
 
+#include <cryptopp/osrng.h>
+
 #include "DwmSvnTag.hh"
 #include "DwmUnitAssert.hh"
 #include "DwmAuthSymCrypto.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.1.3/tests/TestDwmAuthSymCrypto.cc 8556 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.2.0/tests/TestDwmAuthSymCrypto.cc 9842 $");
 
 using namespace std;
 using namespace Dwm;
 using namespace Dwm::Auth;
 
+static const string  g_keys[] = {
+  "WTF?WMC?Idunno!",
+  "a12345678901234",
+  "#@%$&^()[]abcde",
+  ""
+};
+
+static const string g_ivs[] = {
+  string("12345678"),
+  string("abcdEFGH"),
+  string("!@#$%^&("),
+  string("")
+};
+
+//----------------------------------------------------------------------------
+//!  
+//----------------------------------------------------------------------------
+static void TestBinary()
+{
+#ifdef __linux__
+  CryptoPP::NonblockingRng  rng;
+#else
+  CryptoPP::BlockingRng  rng;
+#endif
+
+  uint8_t  data[4096];
+  rng.GenerateBlock(data, 4096);
+
+  for (int j = 0; (! g_keys[j].empty()); ++j) {
+    for (int k = 0; (! g_ivs[k].empty()); ++k) {
+      string  cipher = SymCrypto::Encrypt(g_keys[j], g_ivs[k],
+                                          data, 4096);
+      string  plain = SymCrypto::Decrypt(g_keys[j], g_ivs[k], cipher);
+      UnitAssert(memcmp(plain.c_str(), data, 4096) == 0);
+      UnitAssert(plain.size() == 4096);
+    }
+  }
+  return;
+}
+
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
@@ -61,31 +103,19 @@ int main(int argc, char *argv[])
     ""
   };
 
-  const string  keys[] = {
-    "WTF?WMC?Idunno!",
-    "a12345678901234",
-    "#@%$&^()[]abcde",
-    ""
-  };
-
-  const string ivs[] = {
-    string("12345678"),
-    string("abcdEFGH"),
-    string("!@#$%^&("),
-    string("")
-  };
-
   string  plain, cipher;
   for (int i = 0; (! plainTexts[i].empty()); ++i) {
-    for (int j = 0; (! keys[j].empty()); ++j) {
-      for (int k = 0; (! ivs[k].empty()); ++k) {
-        cipher = SymCrypto::Encrypt(keys[j], ivs[k], plainTexts[i]);
-        plain = SymCrypto::Decrypt(keys[j], ivs[k], cipher);
+    for (int j = 0; (! g_keys[j].empty()); ++j) {
+      for (int k = 0; (! g_ivs[k].empty()); ++k) {
+        cipher = SymCrypto::Encrypt(g_keys[j], g_ivs[k], plainTexts[i]);
+        plain = SymCrypto::Decrypt(g_keys[j], g_ivs[k], cipher);
         UnitAssert(plain == plainTexts[i]);
       }
     }
   }
 
+  TestBinary();
+  
   int  rc;
   if (Assertions::Total().Failed()) {
     Assertions::Print(std::cerr, true);
